summaryrefslogtreecommitdiffstats
path: root/epan/dissectors/packet-sdp.h
diff options
context:
space:
mode:
authorDaniel Baumann <daniel.baumann@progress-linux.org>2024-09-19 04:14:26 +0000
committerDaniel Baumann <daniel.baumann@progress-linux.org>2024-09-19 04:14:26 +0000
commitc4e8a3222648fcf22ca207f1815ebbf7cd144eeb (patch)
tree93d5c6aa93d9987680dd1adad5685e2ad698f223 /epan/dissectors/packet-sdp.h
parentAdding upstream version 4.2.6. (diff)
downloadwireshark-upstream.tar.xz
wireshark-upstream.zip
Adding upstream version 4.4.0.upstream/4.4.0upstream
Signed-off-by: Daniel Baumann <daniel.baumann@progress-linux.org>
Diffstat (limited to 'epan/dissectors/packet-sdp.h')
-rw-r--r--epan/dissectors/packet-sdp.h21
1 files changed, 9 insertions, 12 deletions
diff --git a/epan/dissectors/packet-sdp.h b/epan/dissectors/packet-sdp.h
index 31a9d776..634b5b19 100644
--- a/epan/dissectors/packet-sdp.h
+++ b/epan/dissectors/packet-sdp.h
@@ -16,7 +16,7 @@
#define __PACKET_SDP_H__
typedef struct _sdp_packet_info {
- gchar summary_str[50]; /* SDP summary string for VoIP calls graph analysis */
+ char summary_str[50]; /* SDP summary string for VoIP calls graph analysis */
} sdp_packet_info;
enum sdp_exchange_type
@@ -29,29 +29,26 @@ enum sdp_exchange_type
enum sdp_trace_id_hf_type
{
SDP_TRACE_ID_HF_TYPE_STR = 0, /* */
- SDP_TRACE_ID_HF_TYPE_GUINT32 /* */
+ SDP_TRACE_ID_HF_TYPE_UINT32 /* */
};
/*
* Information needed to set up a trace id in RTP(t ex SIP CallId )
*/
-#define SDP_INFO_OFFSET 10 /* Max number of SDP data occurensies in a single frame */
-
-typedef struct _sdp_conv_info {
- wmem_array_t *sdp_setup_info_list;
-} sdp_conv_info_t;
+#define SDP_INFO_OFFSET 10 /* Max number of SDP data occurrences in a single frame */
typedef struct _sdp_setup_info {
int hf_id; /* Header field to use */
- enum sdp_trace_id_hf_type hf_type; /* Indicates which of the following variables to use( add guint32 etc as needed)*/
- gboolean add_hidden;
+ enum sdp_trace_id_hf_type hf_type; /* Indicates which of the following variables to use( add uint32_t etc as needed)*/
+ bool add_hidden;
+ bool is_osmux;
union {
- gchar *str; /* The trace id if the hf_type is str */
- guint32 num; /* Numerical trace id */
+ char *str; /* The trace id if the hf_type is str */
+ uint32_t num; /* Numerical trace id */
} trace_id;
} sdp_setup_info_t;
-extern void setup_sdp_transport(tvbuff_t *tvb, packet_info *pinfo, enum sdp_exchange_type type, int request_frame, const gboolean delay, sdp_setup_info_t *setup_info);
+extern void setup_sdp_transport(tvbuff_t *tvb, packet_info *pinfo, enum sdp_exchange_type type, int request_frame, const bool delay, sdp_setup_info_t *setup_info);
/* Handles duplicate OFFER packets so they don't end up processed by dissect_sdp(). This can probably
* be removed when all higher layer dissectors properly handle SDP themselves with setup_sdp_transport()
*/